--- a/wim/WimServer/inc/WimServer.h Tue Feb 02 00:44:34 2010 +0200
+++ b/wim/WimServer/inc/WimServer.h Fri Feb 19 23:42:03 2010 +0200
@@ -1,5 +1,5 @@
/*
-* Copyright (c) 2003-2009 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2003-2010 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
@@ -137,20 +137,20 @@
* close.
*
* @lib
- * @since S60
+ * @since S60
*/
class CShutdown : public CTimer
- {
+ {
public:
-
+
inline CShutdown();
-
+
inline void ConstructL();
-
+
inline void Start();
-
+
private:
-
+
void RunL();
};
@@ -219,23 +219,26 @@
/**
* Initializes WIMI if not yet initialized.
* In initalization WIM data from card is fetched to WIMI.
+ * @param aMessage Client request, completed to return initialization status.
* @return void
*/
void WimInitialize( const RMessage2& aMessage );
-
+
/**
* Cancel Initializes WIMI if not yet initialized.
* Stop the apdu sending
+ * @param aMessage Client request, completed with KErrNone.
* @return void
*/
void CancelWimInitialize( const RMessage2& aMessage );
/**
* Set WimInitialized flag
* @param aInitialized ETrue/EFalse whether WIM is initialized
* @return void
*/
- static void SetWimInitialized( TBool aInitialized, TInt aStatus );
+ static void SetWimInitialized( TBool aInitialized, TInt aWimStatus );
/**
* Get TrustSettingsStore pointer
@@ -276,17 +279,17 @@
* @param TBool Refresh event received from SAT.
*/
void SetRefreshNotificationReceived( TBool aValue );
-
+
/**
* Return the pointer of Timer
*/
CWimTimer* WimTimer();
-
+
/**
* Interface derived from MWimTimerListener
*/
void TimerExpired();
-
+
#ifdef WIMSERVER_SHUTDOWN
void AddSession();
@@ -421,7 +424,7 @@
// Pointer to CServer object
static CWimServer* iWimServer;
// Callback structure for WIMI
-
+
/**
* Current service is accessing physical token.
* Used to determine if SIM Refresh can be allowed.
@@ -444,13 +447,13 @@
*
*/
CWimBTSapObserver* iBTSapObserver;
-
- // Pointer to Timer. Owned
- CWimTimer* iWimTimer;
+
+ // Pointer to Timer. Owned
+ CWimTimer* iWimTimer;
-#ifdef WIMSERVER_SHUTDOWN
+#ifdef WIMSERVER_SHUTDOWN
CShutdown iShutdown;
-#endif
+#endif
};
#endif // CWIMSERVER_H
@@ -219,23 +219,26 @@
/**
* Set WimInitialized flag
- * @param aInitialized ETrue/EFalse whether WIM is initialized
+ * @param aInitialized ETrue/EFalse whether WIM is initialized
+ * @param aWimStatus KErrNone or other error code
* @return void
*/